home | help
GMX-VANHOVE(1)			     GROMACS			  GMX-VANHOVE(1)

NAME
     gmx-vanhove - Compute Van Hove displacement and correlation functions

SYNOPSIS
	gmx vanhove [-f [<.xtc/.trr/...>]] [-s [<.tpr/.gro/...>]] [-n [<.ndx>]]
		    [-om [<.xpm>]] [-or [<.xvg>]] [-ot [<.xvg>]] [-b <time>]
		    [-e <time>] [-dt <time>] [-[no]w] [-xvg <enum>]
		    [-sqrt <real>] [-fm <int>] [-rmax <real>] [-rbin <real>]
		    [-mmax <real>] [-nlevels <int>] [-nr <int>] [-fr <int>]
		    [-rt <real>] [-ft <int>]

DESCRIPTION
     gmx  vanhove  computes  the  Van  Hove  correlation function.  The Van Hove
     G(r,t) is the probability that a particle that is at r_0 at time  zero  can
     be  found	at position r_0+r at time t.  gmx vanhove determines G not for a
     vector r, but for the length of r.  Thus it gives the  probability  that  a
     particle moves a distance of r in time t.	Jumps across the periodic bound-
     aries  are  removed.   Corrections are made for scaling due to isotropic or
     anisotropic pressure coupling.

     With option -om the whole matrix can be written as a function of t and r or
     as a function of sqrt(t) and r (option -sqrt).

     With option -or the Van Hove function is plotted for one or more values  of
     t.  Option  -nr sets the number of times, option -fr the number spacing be-
     tween the times.  The binwidth is set with option -rbin. The number of bins
     is determined automatically.

     With option -ot the integral up to a certain distance (option -rt) is plot-
     ted as a function of time.

     For all frames that are read the coordinates of the selected particles  are
     stored  in  memory. Therefore the program may use a lot of memory.  For op-
     tions -om and -ot the program may be slow.  This is because the calculation
     scales as the number of frames times -fm or -ft.  Note that  with	the  -dt
     option the memory usage and calculation time can be reduced.

OPTIONS
     Options to specify input files:

     -f [<.xtc/.trr/...>] (traj.xtc)
	    Trajectory: xtc trr cpt gro g96 pdb tng h5md

     -s [<.tpr/.gro/...>] (topol.tpr)
	    Structure+mass(db): tpr gro g96 pdb brk ent

     -n [<.ndx>] (index.ndx) (Optional)
	    Index file

     Options to specify output files:

     -om [<.xpm>] (vanhove.xpm) (Optional)
	    X PixMap compatible matrix file

     -or [<.xvg>] (vanhove_r.xvg) (Optional)
	    xvgr/xmgr file

     -ot [<.xvg>] (vanhove_t.xvg) (Optional)
	    xvgr/xmgr file

     Other options:

     -b <time> (0)
	    Time of first frame to read from trajectory (default unit ps)

     -e <time> (0)
	    Time of last frame to read from trajectory (default unit ps)

     -dt <time> (0)
	    Only use frame when t MOD dt = first time (default unit ps)

     -[no]w (no)
	    View output .xvg, .xpm, .eps and .pdb files

     -xvg <enum> (xmgrace)
	    xvg plot formatting: xmgrace, xmgr, none

     -sqrt <real> (0)
	    Use sqrt(t) on the matrix axis which binspacing # in sqrt(ps)

     -fm <int> (0)
	    Number of frames in the matrix, 0 is plot all

     -rmax <real> (2)
	    Maximum r in the matrix (nm)

     -rbin <real> (0.01)
	    Binwidth in the matrix and for -or (nm)

     -mmax <real> (0)
	    Maximum density in the matrix, 0 is calculate (1/nm)

     -nlevels <int> (81)
	    Number of levels in the matrix

     -nr <int> (1)
	    Number of curves for the -or output

     -fr <int> (0)
	    Frame spacing for the -or output

     -rt <real> (0)
	    Integration limit for the -ot output (nm)

     -ft <int> (0)
	    Number of frames in the -ot output, 0 is plot all

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			  GMX-VANHOVE(1)

home | help